@@ -1,8 +1,5 @@
 from instruction_ner.model import Model
 
-__version__ = "0.1"
-
 __all__ = [
-    "Model",
-    "__version__"
+    "Model"
 ]
